@@ -12,9 +12,7 @@ __doc__ = r"""This script will clean a apppath directory of an app"""
 def clean_arg():
     """"""
     parser = argparse.ArgumentParser(description="Apppath Clean Path")
-    parser.add_argument(
-        "APP_NAME", metavar="Name", type=str, help="App name to clean AppPath for"
-    )
+    parser.add_argument("APP_NAME", metavar="Name", type=str, help="App name to clean AppPath for")
     parser.add_argument(
         "--DIR",
         "-d",
@@ -25,16 +23,16 @@ def clean_arg():
     )
 
     args = parser.parse_args()
-    PROJECT_APP_PATH = AppPath(args.APP_NAME)
+    project_app_path = AppPath(args.APP_NAME)
 
     if args.DIR == "data":
-        directory = PROJECT_APP_PATH.user_data
+        directory = project_app_path.user_data
     elif args.DIR == "config":
-        directory = PROJECT_APP_PATH.user_config
+        directory = project_app_path.user_config
     elif args.DIR == "cache":
-        directory = PROJECT_APP_PATH.user_cache
+        directory = project_app_path.user_cache
     elif args.DIR == "logs":
-        directory = PROJECT_APP_PATH.user_log
+        directory = project_app_path.user_log
     else:
         raise NotADirectoryError(args.DIR)
 
