@@ -1,8 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import argparse
-import subprocess
-import sys
 
 from apppath import AppPath
 
@@ -15,9 +13,7 @@ from apppath.system_open_path_utilities import AppPathSubDirEnum, open_app_path
 def open_arg():
     """"""
     parser = argparse.ArgumentParser(description="Apppath Open Path")
-    parser.add_argument(
-        "APP_NAME", metavar="Name", type=str, help="App name to open AppPath for"
-    )
+    parser.add_argument("APP_NAME", metavar="Name", type=str, help="App name to open AppPath for")
     parser.add_argument(
         "--SITE",
         "-s",
